import { graphql } from "@/gql";

export type PigName =
  | "logo"
  | "music"
  | "drink"
  | "dance"
  | "point"
  | "student"
  | "listen"
  | "guard"
  | "key"
  | "chill"
  | "peek";

export const PIG_NAMES = [
  "logo",
  "music",
  "drink",
  "dance",
  "point",
  "student",
  "listen",
  "guard",
  "key",
  "chill",
  "peek",
];

export function randomElement(array: any[]): any | undefined {
  return array.length
    ? array[Math.floor(Math.random() * array.length)]
    : undefined;
}

export function unique<T>(array: any[]): any[] {
  return Array.from(array.reduce((set, item) => set.add(item), new Set()));
}

export function stripWhitespace(s: string): string {
  return s.replace(/\s/g, "");
}

export function formatPhoneE164(phone: string): string {
  phone = stripWhitespace(phone);
  if (phone.startsWith("+") || phone.length != 8) {
    return phone;
  }
  return "+47" + phone;
}

export function formatNorwegianPhoneNumber(phone: string): string {
  if (phone.startsWith("+47")) {
    const local = phone.substring(3);
    if (local.length === 8) {
      return `${local.substring(0, 3)} ${local.substring(
        3,
        5
      )} ${local.substring(5)}`;
    }
  }
  return phone;
}

const OneLevelOfBlocksFragmentDefinition = graphql(`
  fragment OneLevelOfBlocks on StreamFieldInterface {
    id
    blockType
    field
    ... on RichTextBlock {
      rawValue
      value
    }
    ... on ImageWithTextBlock {
      image {
        ...Image
      }
      imageFormat
      text
    }
    ... on ImageSliderBlock {
      images {
        ... on ImageSliderItemBlock {
          image {
            ...Image
          }
          text
        }
      }
    }
    ... on HorizontalRuleBlock {
      color
    }
    ... on FeaturedBlock {
      title
      featuredBlockText: text
      linkText
      imagePosition
      backgroundColor
      featuredPage {
        contentType
        pageType
        url
        ... on EventPage {
          featuredImage {
            ...Image
          }
        }
        ... on NewsPage {
          featuredImage {
            ...Image
          }
        }
      }
      featuredImageOverride {
        ...Image
      }
    }
    ... on ContactListBlock {
      items {
        blockType
        ... on ContactEntityBlock {
          contactEntity {
            ...ContactEntity
          }
        }
      }
    }
  }
`);

const BlockFragmentDefinition = graphql(`
  fragment Blocks on StreamFieldInterface {
    ... on PageSectionBlock {
      title
      backgroundColor
      body {
        ...OneLevelOfBlocks
      }
    }
    ... on ContactSectionBlock {
      title
      text
      blocks {
        ... on ContactSubsectionBlock {
          title
          text
          blocks {
            ...OneLevelOfBlocks
          }
        }
        ...OneLevelOfBlocks
      }
    }
    ...OneLevelOfBlocks
  }
`);

const ImageFragmentDefinition = graphql(`
  fragment Image on CustomImage {
    id
    url
    width
    height
    alt
    attribution
  }
`);

const ContactEntityFragmentDefinition = graphql(`
  fragment ContactEntity on ContactEntity {
    id
    name
    contactType
    title
    email
    phoneNumber
    image {
      ...Image
    }
  }
`);
